# Evolutionary Computation Bestiary  
[![DOI](https://zenodo.org/badge/54759561.svg)](https://zenodo.org/badge/latestdoi/54759561)

Updated 2018-06-19   
***  
> "Till now, madness has been thought a small island in an ocean of sanity. I am beginning to suspect that it is not an island at all but a continent." -- [Machado de Assis](https://en.wikipedia.org/wiki/Machado_de_Assis), *[The Psychiatrist](https://en.wikipedia.org/wiki/O_alienista)*.

***

## Introduction

The field of meta-heuristic search algorithms has a long history of finding inspiration in 
natural systems. Starting from classics such as Genetic Algorithms and Ant Colony Optimization, 
the last two decades have witnessed a fireworks-style explosion (pun intended) of natural 
(and sometimes supernatural) heuristics - from Birds and Bees to Zombies and Reincarnation.

The goal of the Evolutionary Computation Bestiary is to catalog the, ermm... exuberance of 
the meta-heuristic "eco-system". We try to keep a list of the many different animals, plants, 
microbes, natural phenomena and supernatural activities that can be spotted in the wild lands 
of the metaphor-based computation literature.

While we personally believe that the literature could do with more mathematics and less 
marsupials, and that we, as a community, should grow past this metaphor-rich phase in our 
field's history (a bit like chemistry outgrew alchemy), please note that this list makes no 
claims about the scientific quality of the papers listed. The EC Bestiary puts classic works of 
the metaheuristics literature (e.g., GAs, ACO) and some that describe their methods in mostly 
metaphor-free language (e.g., JTF, CFO) side by side with others for which the scientific rigor 
is, to put it mildly, lacking. In short, it is not a Hall of Fame of algorithms - think of it 
more as [The island of Doctor Moreau](https://en.wikipedia.org/wiki/The_Island_of_Doctor_Moreau): 
a place with a few good creatures, but which are vastly outnumbered by mindless beasts.

Finally, if you know a metaphor-based method that is not listed here, or if you know of an 
earlier mention of a listed method, please see the bottom of the page on how to contribute!

******

## The Bestiary
![BioHeuristics GO](img/BioHeuristics%20GO.png)

### A
- **<u>African Buffalo</u>**: Odili JB, Kahar MNM (2016). “Solving the Traveling Salesman's Problem Using the African Buffalo Optimization.” _Computational Intelligence and Neuroscience_, *2016*, 1-12. doi: [10.1155/2016/1510256 ](https://doi.org/10.1155/2016/1510256 )
- **<u>Algae</u>**: Uymaz SA, Tezel G, Yel E (2015). “Artificial algae algorithm (AAA) for nonlinear global optimization.” _Applied Soft Computing_, *31*, 153-171. doi: [10.1016/j.asoc.2015.03.003 ](https://doi.org/10.1016/j.asoc.2015.03.003 )
- **<u>Amoeba</u>**: Wang H, Lu X, Zhang X, Wang Q, Deng Y (2014). “A Bio-Inspired Method for the Constrained Shortest Path Problem.” _The Scientific World Journal_, *2014*, 1-11. doi: [10.1155/2014/271280 ](https://doi.org/10.1155/2014/271280 )
- **<u>Anarchic Society</u>**: Shayeghi H, Dadashpour J (2012). “Anarchic Society Optimization Based PID Control of an Automatic Voltage Regulator (AVR) System.” _Electrical and Electronic Engineering_, *2*(4), 199-207. doi: [10.5923/j.eee.20120204.05 ](https://doi.org/10.5923/j.eee.20120204.05 )
- **<u>Andean Condors</u>**: Almonacid B, Soto R (2018). “Andean Condor Algorithm for cell formation problems.” _Natural Computing_. doi: [10.1007/s11047-018-9675-0 ](https://doi.org/10.1007/s11047-018-9675-0 )
- **<u>Animal Behavior: Hunting</u>**: Naderi B, Khalili M, Khamseh AA (2014). “Mathematical models and a hunting search algorithm for the no-wait flowshop scheduling with parallel machines.” _International Journal of Production Research_, *52*(9), 2667-2681. doi: [10.1080/00207543.2013.871389 ](https://doi.org/10.1080/00207543.2013.871389 )
- **<u>Animal Behavior: Predation</u>**: Tilahun SL, Ong HC (2015). “Prey-Predator Algorithm: A New Metaheuristic Algorithm for Optimization Problems.” _International Journal of Information Technology \& Decision Making_, *14*(06), 1331-1352. doi: [10.1142/s021962201450031x ](https://doi.org/10.1142/s021962201450031x )
- **<u>Animal Behavior: Searching</u>**: He S, Wu Q, Saunders J (2009). “Group Search Optimizer: An Optimization Algorithm Inspired by Animal Searching Behavior.” _IEEE Transactions on Evolutionary Computation_, *13*(5), 973-990. doi: [10.1109/tevc.2009.2011992 ](https://doi.org/10.1109/tevc.2009.2011992 )
- **<u>Ant Colony</u>**: Maniezzo A (1992). “Distributed optimization by ant colonies.” In _Toward a Practice of Autonomous Systems: Proceedings of the First European Conference on Artificial Life_, 134. Mit Press.
- **<u>Ant Lion</u>**: Mirjalili S (2015). “The Ant Lion Optimizer.” _Advances in Engineering Software_, *83*, 80-98. doi: [10.1016/j.advengsoft.2015.01.010 ](https://doi.org/10.1016/j.advengsoft.2015.01.010 )
- **<u>Antibodies</u>**: De Castro LN, Von Zuben FJ (2000). “The clonal selection algorithm with engineering applications.” In _Proceedings of GECCO_, volume 2000, 36-39.

### B
- **<u>Bachelors</u>**: Hu TC, Kahng AB, Tsao CA (1995). “Old Bachelor Acceptance: A New Class of Non-Monotone Threshold Accepting Methods.” _ORSA Journal on Computing_, *7*(4), 417-425. doi: [10.1287/ijoc.7.4.417 ](https://doi.org/10.1287/ijoc.7.4.417 )
- **<u>Bacteria: Bacterial Chemotaxis</u>**: Muller S, Marchetto J, Airaghi S, Kournoutsakos P (2002). “Optimization based on bacterial chemotaxis.” _IEEE Transactions on Evolutionary Computation_, *6*(1), 16-29. doi: [10.1109/4235.985689 ](https://doi.org/10.1109/4235.985689 )
- **<u>Bacteria: Bacterial Foraging</u>**: Passino K (2002). “Biomimicry of bacterial foraging for distributed optimization and control.” _IEEE Control Systems Magazine_, *22*(3), 52-67. doi: [10.1109/mcs.2002.1004010 ](https://doi.org/10.1109/mcs.2002.1004010 )
- **<u>Bacteria: Bacterial Swarming</u>**: Chu Y, Mi H, Liao H, Ji Z, Wu QH (2008). “A Fast Bacterial Swarming Algorithm for high-dimensional function optimization.” In _2008 IEEE Congress on Evolutionary Computation (IEEE World Congress on Computational Intelligence)_. doi: [10.1109/cec.2008.4631222 ](https://doi.org/10.1109/cec.2008.4631222 )
- **<u>Bacteria: Magnetotactic Bacteria</u>**: Mo H, Xu L (2013). “Magnetotactic bacteria optimization algorithm for multimodal optimization.” In _2013 IEEE Symposium on Swarm Intelligence (SIS)_. doi: [10.1109/sis.2013.6615185 ](https://doi.org/10.1109/sis.2013.6615185 )
- **<u>Bats</u>**: Yang X (2010). “A new metaheuristic bat-inspired algorithm.” In _Nature inspired cooperative strategies for optimization (NICSO 2010)_, 65-74. Springer.
- **<u>Bees: Bee Colonies</u>**: Teodorovic D, Lucic P, Markovic G, Orco MD (2006). “Bee Colony Optimization: Principles and Applications.” In _2006 8th Seminar on Neural Network Applications in Electrical Engineering_. doi: [10.1109/neurel.2006.341200 ](https://doi.org/10.1109/neurel.2006.341200 )
- **<u>Bees: Bumblebees</u>**: Comellas F, Martinez-Navarro J (2009). “Bumblebees.” In _Proceedings of the first ACM/SIGEVO Summit on Genetic and Evolutionary Computation - GEC \textquotesingle09_. doi: [10.1145/1543834.1543949 ](https://doi.org/10.1145/1543834.1543949 )
- **<u>Bees: Honey Bee Marriages</u>**: Abbass H (2001). “MBO: marriage in honey bees optimization-a Haplometrosis polygynous swarming approach.” In _Proceedings of the 2001 Congress on Evolutionary Computation (IEEE Cat. No.01TH8546)_. doi: [10.1109/cec.2001.934391 ](https://doi.org/10.1109/cec.2001.934391 )
- **<u>Bees: Queen Bees</u>**: Jung SH (2003). “Queen-bee evolution for genetic algorithms.” _Electronics Letters_, *39*(6), 575. doi: [10.1049/el:20030383 ](https://doi.org/10.1049/el:20030383 )
- **<u>Beetles</u>**: Kallioras NA, Lagaros ND, Avtzis DN (2018). “Pity beetle algorithm \textendash A new metaheuristic inspired by the behavior of bark beetles.” _Advances in Engineering Software_, *121*, 147-166. doi: [10.1016/j.advengsoft.2018.04.007 ](https://doi.org/10.1016/j.advengsoft.2018.04.007 )
- **<u>Big Bang</u>**: Erol OK, Eksin I (2006). “A new optimization method: Big Bang\textendashBig Crunch.” _Advances in Engineering Software_, *37*(2), 106-111. doi: [10.1016/j.advengsoft.2005.04.005 ](https://doi.org/10.1016/j.advengsoft.2005.04.005 )
- **<u>Biogeography</u>**: Simon D (2008). “Biogeography-Based Optimization.” _IEEE Transactions on Evolutionary Computation_, *12*(6), 702-713. doi: [10.1109/tevc.2008.919004 ](https://doi.org/10.1109/tevc.2008.919004 )
- **<u>Birds: Bird Migrations</u>**: Duman E, Uysal M, Alkaya AF (2012). “Migrating Birds Optimization: A new metaheuristic approach and its performance on quadratic assignment problem.” _Information Sciences_, *217*, 65-77. doi: [10.1016/j.ins.2012.06.032 ](https://doi.org/10.1016/j.ins.2012.06.032 )
- **<u>Birds: Birds Mating</u>**: Askarzadeh A (2014). “Bird mating optimizer: An optimization algorithm inspired by bird mating strategies.” _Communications in Nonlinear Science and Numerical Simulation_, *19*(4), 1213-1228. doi: [10.1016/j.cnsns.2013.08.027 ](https://doi.org/10.1016/j.cnsns.2013.08.027 )
- **<u>Black Holes</u>**: Hatamlou A (2013). “Black hole: A new heuristic optimization approach for data clustering.” _Information Sciences_, *222*, 175-184. doi: [10.1016/j.ins.2012.08.023 ](https://doi.org/10.1016/j.ins.2012.08.023 )
- **<u>Blind Naked Mole Rats</u>**: Taherdangkoo M, Shirzadi MH, Yazdi M, Bagheri MH (2013). “A robust clustering method based on blind, naked mole-rats (BNMR) algorithm.” _Swarm and Evolutionary Computation_, *10*, 1-11. doi: [10.1016/j.swevo.2013.01.001 ](https://doi.org/10.1016/j.swevo.2013.01.001 )
- **<u>Brainstorming</u>**: Shi Y (2011). “An Optimization Algorithm Based on Brainstorming Process.” _International Journal of Swarm Intelligence Research_, *2*(4), 35-62. doi: [10.4018/ijsir.2011100103 ](https://doi.org/10.4018/ijsir.2011100103 )
- **<u>Butterflies: Monarch Butterflies</u>**: Wang G, Deb S, Cui Z (2015). “Monarch butterfly optimization.” _Neural Computing and Applications_. doi: [10.1007/s00521-015-1923-y ](https://doi.org/10.1007/s00521-015-1923-y )

### C
- **<u>Camels</u>**: M. K. Ibrahim RSA (2016). “Novel Optimization Algorithm Inspired by Camel Traveling Behavior.” _Iraq J. Electrical and Electronic Engineering_, *12*(2). doi: [10.1007/s00707-009-0270-4 ](https://doi.org/10.1007/s00707-009-0270-4 )
- **<u>Cancers</u>**: Tang D, Dong S, Jiang Y, Li H, Huang Y (2015). “ITGO: Invasive tumor growth optimization algorithm.” _Applied Soft Computing_, *36*, 670-698. doi: [10.1016/j.asoc.2015.07.045 ](https://doi.org/10.1016/j.asoc.2015.07.045 )
- **<u>Cats</u>**: Chu S, Tsai P, Pan J (2006). “Cat Swarm Optimization.” In _Lecture Notes in Computer Science_, 854-858. Springer Berlin Heidelberg. doi: [10.1007/978-3-540-36668-3_94 ](https://doi.org/10.1007/978-3-540-36668-3_94 )
- **<u>Central Force</u>**: Formato RA (2007). “CENTRAL FORCE OPTIMIZATION: A NEW METAHEURISTIC WITH APPLICATIONS IN APPLIED ELECTROMAGNETICS.” _Progress In Electromagnetics Research_, *77*, 425-491. doi: [10.2528/pier07082403 ](https://doi.org/10.2528/pier07082403 )
- **<u>Charged Systems</u>**: Kaveh A, Talatahari S (2010). “A novel heuristic optimization method: charged system search.” _Acta Mechanica_, *213*(3-4), 267-289. doi: [10.1007/s00707-009-0270-4 ](https://doi.org/10.1007/s00707-009-0270-4 )
- **<u>Chemical Reactions</u>**: Alatas B (2011). “ACROA: Artificial Chemical Reaction Optimization Algorithm for global optimization.” _Expert Systems with Applications_, *38*(10), 13170-13180. doi: [10.1016/j.eswa.2011.04.126 ](https://doi.org/10.1016/j.eswa.2011.04.126 )
- **<u>Chickens: Chicken Laying Eggs</u>**: Hosseini E (2017). “Laying Chicken Algorithm: A New Meta-Heuristic Approach to Solve Continuous Programming Problems.” _Journal of Applied \& Computational Mathematics_, *06*(01). doi: [10.4172/2168-9679.1000344 ](https://doi.org/10.4172/2168-9679.1000344 )
- **<u>Chickens: Chicken Swarms</u>**: Meng X, Liu Y, Gao X, Zhang H (2014). “A New Bio-inspired Algorithm: Chicken Swarm Optimization.” In _Lecture Notes in Computer Science_, 86-94. Springer International Publishing. doi: [10.1007/978-3-319-11857-4_10 ](https://doi.org/10.1007/978-3-319-11857-4_10 )
- **<u>Clouds</u>**: YAN G, HAO Z (2013). “A NOVEL OPTIMIZATION ALGORITHM BASED ON ATMOSPHERE CLOUDS MODEL.” _International Journal of Computational Intelligence and Applications_, *12*(01), 1350002. doi: [10.1142/s1469026813500028 ](https://doi.org/10.1142/s1469026813500028 )
- **<u>Cockroaches</u>**: Obagbuwa IC, Adewumi AO (2014). “An Improved Cockroach Swarm Optimization.” _The Scientific World Journal_, *2014*, 1-13. doi: [10.1155/2014/375358 ](https://doi.org/10.1155/2014/375358 )
- **<u>Colliding Bodies</u>**: Kaveh A, Mahdavi V (2014). “Colliding bodies optimization: A novel meta-heuristic method.” _Computers \& Structures_, *139*, 18-27. doi: [10.1016/j.compstruc.2014.04.005 ](https://doi.org/10.1016/j.compstruc.2014.04.005 )
- **<u>Community of scientists</u>**: Alfredo M, Valentino S (2012). “Community of scientist optimization: An autonomy oriented approach to distributed optimization.” _AI Communications_, *25*(2), 157–172. ISSN 0921-7126, doi: [10.3233/AIC-2012-0526 ](https://doi.org/10.3233/AIC-2012-0526 )
- **<u>Consultants</u>**: Iordache S (2010). “Consultant-guided search.” In _Proceedings of the 12th annual conference on Genetic and evolutionary computation - GECCO \textquotesingle10_. doi: [10.1145/1830483.1830526 ](https://doi.org/10.1145/1830483.1830526 )
- **<u>Coral Reefs</u>**: Salcedo-Sanz S, Ser JD, Landa-Torres I, Gil-López S, Portilla-Figueras JA (2014). “The Coral Reefs Optimization Algorithm: A Novel Metaheuristic for Efficiently Solving Optimization Problems.” _The Scientific World Journal_, *2014*, 1-15. doi: [10.1155/2014/739768 ](https://doi.org/10.1155/2014/739768 )
- **<u>Crows</u>**: Askarzadeh A (2016). “A novel metaheuristic method for solving constrained engineering optimization problems: Crow search algorithm.” _Computers \& Structures_, *169*, 1-12. doi: [10.1016/j.compstruc.2016.03.001 ](https://doi.org/10.1016/j.compstruc.2016.03.001 )
- **<u>Crystal Energy</u>**: Feng X, Ma M, Yu H (2014). “Crystal Energy Optimization Algorithm.” _Computational Intelligence_, *32*(2), 284-322. doi: [10.1111/coin.12053 ](https://doi.org/10.1111/coin.12053 )
- **<u>Cuckoos</u>**: Yang X, Deb S (2009). “Cuckoo Search via L\&\#x00E9$\mathsemicolon$vy flights.” In _2009 World Congress on Nature \& Biologically Inspired Computing (NaBIC)_. doi: [10.1109/nabic.2009.5393690 ](https://doi.org/10.1109/nabic.2009.5393690 )

### D
- **<u>Deer: Scottish Red Deer</u>**: Fard AF, Hajiaghaei-Keshteli M (2016). “Red Deer Algorithm (RDA); A New Optimization Algorithm Inspired by Red Deers’ Mating.” In _International Conference on Industrial Engineering, IEEE.,(2016 e)_, 33-34.
- **<u>Dogs</u>**: Subramanian C, Sekar A, Subramanian K (2013). “A New Engineering Optimization Method: African Wild Dog Algorithm.” _International Journal of Soft Computing_, *8*(3).
- **<u>Dolphins: Dolphin Echolocation</u>**: Kaveh A, Farhoudi N (2013). “A new optimization method: Dolphin echolocation.” _Advances in Engineering Software_, *59*, 53-70. doi: [10.1016/j.advengsoft.2013.03.004 ](https://doi.org/10.1016/j.advengsoft.2013.03.004 )
- **<u>Dolphins: Dolphin Partners</u>**: Shiqin Y, Jianjun J, Guangxing Y (2009). “A Dolphin Partner Optimization.” In _2009 WRI Global Congress on Intelligent Systems_. doi: [10.1109/gcis.2009.464 ](https://doi.org/10.1109/gcis.2009.464 )
- **<u>Dragonflies</u>**: Mirjalili S (2015). “Dragonfly algorithm: a new meta-heuristic optimization technique for solving single-objective, discrete, and multi-objective problems.” _Neural Computing and Applications_, *27*(4), 1053-1073. doi: [10.1007/s00521-015-1920-1 ](https://doi.org/10.1007/s00521-015-1920-1 )
- **<u>Duelists</u>**: Biyanto TR, Fibrianto HY, Nugroho G, Hatta AM, Listijorini E, Budiati T, Huda H (2016). “Duelist Algorithm: An Algorithm Inspired by How Duelist Improve Their Capabilities in a Duel.” In Tan Y, Shi Y, Niu B (eds.), _Advances in Swarm Intelligence_, 39-47. ISBN 978-3-319-41000-5.

### E
- **<u>Eagles</u>**: Yang X, Deb S (2010). “Eagle Strategy Using Lévy Walk and Firefly Algorithms for Stochastic Optimization.” In _Nature Inspired Cooperative Strategies for Optimization (NICSO 2010)_, 101-111. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-12538-6_9 ](https://doi.org/10.1007/978-3-642-12538-6_9 )
- **<u>Ecogeography</u>**: Zheng Y, Ling H, Xue J (2014). “Ecogeography-based optimization: Enhancing biogeography-based optimization with ecogeographic barriers and differentiations.” _Computers \& Operations Research_, *50*, 115-127. doi: [10.1016/j.cor.2014.04.013 ](https://doi.org/10.1016/j.cor.2014.04.013 )
- **<u>Ecology</u>**: Parpinelli RS, Lopes HS (2011). “An eco-inspired evolutionary algorithm applied to numerical optimization.” In _2011 Third World Congress on Nature and Biologically Inspired Computing_. doi: [10.1109/nabic.2011.6089631 ](https://doi.org/10.1109/nabic.2011.6089631 )
- **<u>Electromagnetism</u>**: Cuevas E, Oliva D, Zaldivar D, Pérez-Cisneros M, Sossa H (2012). “Circle detection using electro-magnetism optimization.” _Information Sciences_, *182*(1), 40-55. doi: [10.1016/j.ins.2010.12.024 ](https://doi.org/10.1016/j.ins.2010.12.024 )
- **<u>Elephants: Elephant Herds</u>**: Wang G, Deb S, dos S. Coelho L (2015). “Elephant Herding Optimization.” In _2015 3rd International Symposium on Computational and Business Intelligence (ISCBI)_. doi: [10.1109/iscbi.2015.8 ](https://doi.org/10.1109/iscbi.2015.8 )
- **<u>Elephants: Regular Elephants</u>**: Deb S, Fong S, Tian Z (2015). “Elephant Search Algorithm for optimization problems.” In _2015 Tenth International Conference on Digital Information Management (ICDIM)_. doi: [10.1109/icdim.2015.7381893 ](https://doi.org/10.1109/icdim.2015.7381893 )
- **<u>Emotions</u>**: Xu Y, Cui Z, Zeng J (2010). “Social Emotional Optimization Algorithm for Nonlinear Constrained Optimization Problems.” In _Swarm, Evolutionary, and Memetic Computing_, 583-590. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-17563-3_68 ](https://doi.org/10.1007/978-3-642-17563-3_68 )
- **<u>Epidemics</u>**: Huang G (2016). “Artificial infectious disease optimization: A SEIQR epidemic dynamic model-based function optimization~algorithm.” _Swarm and Evolutionary Computation_, *27*, 31-67. doi: [10.1016/j.swevo.2015.09.007 ](https://doi.org/10.1016/j.swevo.2015.09.007 )
- **<u>Experts</u>**: Melo VVD (2014). “Kaizen programming.” In _Proceedings of the 2014 conference on Genetic and evolutionary computation - GECCO \textquotesingle14_. doi: [10.1145/2576768.2598264 ](https://doi.org/10.1145/2576768.2598264 )

### F
- **<u>FIFA World Cup</u>**: Razmjooy N, Khalilpour M, Ramezani M (2016). “A New Meta-Heuristic Optimization Algorithm Inspired by FIFA World Cup Competitions: Theory and Its Application in PID Designing for AVR System.” _Journal of Control, Automation and Electrical Systems_, *27*(4), 419-440. doi: [10.1007/s40313-016-0242-6 ](https://doi.org/10.1007/s40313-016-0242-6 )
- **<u>Fireflies</u>**: Yang X (2009). “Firefly Algorithms for Multimodal Optimization.” In _Stochastic Algorithms: Foundations and Applications_, 169-178. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-04944-6_14 ](https://doi.org/10.1007/978-3-642-04944-6_14 )
- **<u>Fireworks</u>**: Tan Y, Zhu Y (2010). “Fireworks Algorithm for Optimization.” In _Lecture Notes in Computer Science_, 355-364. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-13495-1_44 ](https://doi.org/10.1007/978-3-642-13495-1_44 )
- **<u>Fish: Catfish</u>**: Chuang L, Tsai S, Yang C (2011). “Improved binary particle swarm optimization using catfish effect for feature selection.” _Expert Systems with Applications_, *38*(10), 12699-12707. doi: [10.1016/j.eswa.2011.04.057 ](https://doi.org/10.1016/j.eswa.2011.04.057 )
- **<u>Fish: Cuttlefish</u>**: Eesa A, Abdulazeez A, Orman Z (2013). “Cuttlefish Algorithm - A Novel Bio-Inspired Optimization Algorithm.” _International Journal of Scientific and Engineering Research_, *4*(9), 1978-1986.
- **<u>Fish: Fish Schools</u>**: Filho CJAB, de Lima Neto FB, Lins AJCC, Nascimento AIS, Lima MP (2008). “A novel search algorithm based on fish school behavior.” In _2008 IEEE International Conference on Systems, Man and Cybernetics_. doi: [10.1109/icsmc.2008.4811695 ](https://doi.org/10.1109/icsmc.2008.4811695 )
- **<u>Fish: Fish Swarms</u>**: Li X, Qian J (2003). “Studies on Artificial Fish Swarm Optimization Algorithm Based on Decomposition and Coordination Techniques.” _J Circuits Systems_, *1*, 1-6.
- **<u>Flower Pollination</u>**: Yang X (2012). “Flower Pollination Algorithm for Global Optimization.” In _Unconventional Computation and Natural Computation_, 240-249. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-32894-7_27 ](https://doi.org/10.1007/978-3-642-32894-7_27 )
- **<u>Forests: Forest Regeneration</u>**: Moez H, Kaveh A, Taghizadieh N (2016). “Natural Forest Regeneration Algorithm: A New Meta-Heuristic.” _Iranian Journal of Science and Technology, Transactions of Civil Engineering_, *40*(4), 311-326. doi: [10.1007/s40996-016-0042-z ](https://doi.org/10.1007/s40996-016-0042-z )
- **<u>Forests: Tree Survival</u>**: Ghaemi M, Feizi-Derakhshi M (2014). “Forest Optimization Algorithm.” _Expert Systems with Applications_, *41*(15), 6676-6687. doi: [10.1016/j.eswa.2014.05.009 ](https://doi.org/10.1016/j.eswa.2014.05.009 )
- **<u>Fractals</u>**: Salimi H (2015). “Stochastic Fractal Search: A powerful metaheuristic algorithm.” _Knowledge-Based Systems_, *75*, 1-18. doi: [10.1016/j.knosys.2014.07.025 ](https://doi.org/10.1016/j.knosys.2014.07.025 )
- **<u>Frogs: Japanese Tree Frogs</u>**: Hernández H, Blum C (2012). “Distributed graph coloring: an approach based on the calling behavior of Japanese tree frogs.” _Swarm Intelligence_, *6*(2), 117-150. doi: [10.1007/s11721-012-0067-2 ](https://doi.org/10.1007/s11721-012-0067-2 )
- **<u>Frogs: Leaping</u>**: Eusuff MM, Lansey KE (2003). “Optimization of Water Distribution Network Design Using the Shuffled Frog Leaping Algorithm.” _Journal of Water Resources Planning and Management_, *129*(3), 210-225. doi: 10.1061/(asce)0733-9496(2003)129:3(210) 
- **<u>Fruit Fly</u>**: Pan W (2012). “A new Fruit Fly Optimization Algorithm: Taking the financial distress model as an example.” _Knowledge-Based Systems_, *26*, 69-74. doi: [10.1016/j.knosys.2011.07.001 ](https://doi.org/10.1016/j.knosys.2011.07.001 )

### G
- **<u>Galaxies</u>**: Hosseini HS (2011). “Principal components analysis by the galaxy-based search algorithm: a novel metaheuristic for continuous optimisation.” _International Journal of Computational Science and Engineering_, *6*(1/2), 132. doi: [10.1504/ijcse.2011.041221 ](https://doi.org/10.1504/ijcse.2011.041221 )
- **<u>Gas Molecules: Brownian Motion</u>**: Abdechiri M, Meybodi MR, Bahrami H (2013). “Gases Brownian Motion Optimization: an Algorithm for Optimization (GBMO).” _Applied Soft Computing_, *13*(5), 2932-2946. doi: [10.1016/j.asoc.2012.03.068 ](https://doi.org/10.1016/j.asoc.2012.03.068 )
- **<u>Gas Molecules: Kinetic Energy</u>**: Moein S, Logeswaran R (2014). “KGMO: A swarm optimization algorithm based on the kinetic energy of gas molecules.” _Information Sciences_, *275*, 127-144. doi: [10.1016/j.ins.2014.02.026 ](https://doi.org/10.1016/j.ins.2014.02.026 )
- **<u>Gene Expression</u>**: Ferreira C (2002). “Gene Expression Programming in Problem Solving.” In _Soft Computing and Industry_, 635-653. Springer London. doi: [10.1007/978-1-4471-0123-9_54 ](https://doi.org/10.1007/978-1-4471-0123-9_54 )
- **<u>General Relativity</u>**: Beiranvand H, Rokrok E (2015). “General Relativity Search Algorithm: A Global Optimization Approach.” _International Journal of Computational Intelligence and Applications_, *14*(03), 1550017. doi: [10.1142/s1469026815500170 ](https://doi.org/10.1142/s1469026815500170 )
- **<u>Genes</u>**: Holland J (1975). _Adaptation in Natural and Artificial Systems, An Introductory Analysis with Applications to Biology, Control, and Artificial Intelligence_. MIT Press.
- **<u>Glow Worms</u>**: Krishnanand KN, Ghose D (2008). “Glowworm swarm optimization for simultaneous capture of multiple local optima of multimodal functions.” _Swarm Intelligence_, *3*(2), 87-124. doi: [10.1007/s11721-008-0021-5 ](https://doi.org/10.1007/s11721-008-0021-5 )
- **<u>Grasshoppers</u>**: Saremi S, Mirjalili S, Lewis A (2017). “Grasshopper Optimisation Algorithm: Theory and application.” _Advances in Engineering Software_, *105*, 30-47. doi: [10.1016/j.advengsoft.2017.01.004 ](https://doi.org/10.1016/j.advengsoft.2017.01.004 )
- **<u>Gravitation</u>**: Rashedi E, Nezamabadi-pour H, Saryazdi S (2009). “GSA: A Gravitational Search Algorithm.” _Information Sciences_, *179*(13), 2232-2248. doi: [10.1016/j.ins.2009.03.004 ](https://doi.org/10.1016/j.ins.2009.03.004 )
- **<u>Great Deluge</u>**: Dueck G (1993). “New Optimization Heuristics: The Great Deluge and Record to Record Travel.” _Journal of Computational Physics_, *104*(1), 86-92. doi: [10.1006/jcph.1993.1010 ](https://doi.org/10.1006/jcph.1993.1010 )
- **<u>Grenades</u>**: Ahrari A, Atai AA (2010). “Grenade Explosion Method—A novel tool for optimization of multimodal functions.” _Applied Soft Computing_, *10*(4), 1132-1140. doi: [10.1016/j.asoc.2009.11.032 ](https://doi.org/10.1016/j.asoc.2009.11.032 )
- **<u>Group Counselling</u>**: Eita MA, Fahmy MM (2009). “Group Counseling Optimization: A Novel Approach.” In _Research and Development in Intelligent Systems XXVI_, 195-208. Springer London. doi: [10.1007/978-1-84882-983-1_14 ](https://doi.org/10.1007/978-1-84882-983-1_14 )
- **<u>Group Decision-Making</u>**: Zhang Q, Wang R, Yang J, Ding K, Li Y, Hu J (2017). “Collective decision optimization algorithm: A new heuristic optimization method.” _Neurocomputing_, *221*, 123-137. doi: [10.1016/j.neucom.2016.09.068 ](https://doi.org/10.1016/j.neucom.2016.09.068 )

### H
- **<u>Heart</u>**: Hatamlou A (2014). “Heart: a novel optimization algorithm for cluster analysis.” _Progress in Artificial Intelligence_, *2*(2-3), 167-173. doi: [10.1007/s13748-014-0046-5 ](https://doi.org/10.1007/s13748-014-0046-5 )
- **<u>Hoopoe</u>**: El-Dosuky M, El-Bassiouny A, Hamza T, Rashad M (2012). “New Hoopoe Heuristic Optimization.” _International Journal of Science and Advanced Technology_, *2*(9), 85-90.
- **<u>Hyenas</u>**: Dhiman G, Kumar V (2017). “Spotted hyena optimizer: A novel bio-inspired based metaheuristic technique for engineering applications.” _Advances in Engineering Software_, *114*, 48-70. doi: [10.1016/j.advengsoft.2017.05.014 ](https://doi.org/10.1016/j.advengsoft.2017.05.014 )

### I
- **<u>Interior Design</u>**: Gandomi AH (2014). “Interior search algorithm (ISA): A novel approach for global optimization.” _ISA Transactions_, *53*(4), 1168-1183. doi: [10.1016/j.isatra.2014.03.018 ](https://doi.org/10.1016/j.isatra.2014.03.018 )
- **<u>Invasive Weeds</u>**: Mehrabian A, Lucas C (2006). “A novel numerical optimization algorithm inspired from weed colonization.” _Ecological Informatics_, *1*(4), 355-366. doi: [10.1016/j.ecoinf.2006.07.003 ](https://doi.org/10.1016/j.ecoinf.2006.07.003 )
- **<u>Ions</u>**: Javidy B, Hatamlou A, Mirjalili S (2015). “Ions motion algorithm for solving optimization problems.” _Applied Soft Computing_, *32*, 72-79. doi: [10.1016/j.asoc.2015.03.035 ](https://doi.org/10.1016/j.asoc.2015.03.035 )

### J
- **<u>Jaguars</u>**: Chen C, Tsai Y, Liu I, Lai C, Yeh Y, Kuo S, Chou Y (2015). “A Novel Metaheuristic: Jaguar Algorithm with Learning Behavior.” In _2015 IEEE International Conference on Systems, Man, and Cybernetics_. doi: [10.1109/smc.2015.282 ](https://doi.org/10.1109/smc.2015.282 )

### K
- **<u>Keshtel Duck</u>**: Hajiaghaei-Keshteli M, Aminnayeri M (2014). “Solving the integrated scheduling of production and rail transportation problem by Keshtel algorithm.” _Applied Soft Computing_, *25*, 184-203. doi: [10.1016/j.asoc.2014.09.034 ](https://doi.org/10.1016/j.asoc.2014.09.034 )
- **<u>Kidneys</u>**: Jaddi NS, Alvankarian J, Abdullah S (2017). “Kidney-inspired algorithm for optimization problems.” _Communications in Nonlinear Science and Numerical Simulation_, *42*, 358-369. doi: [10.1016/j.cnsns.2016.06.006 ](https://doi.org/10.1016/j.cnsns.2016.06.006 )
- **<u>Krill</u>**: Gandomi AH, Alavi AH (2012). “Krill herd: A new bio-inspired optimization algorithm.” _Communications in Nonlinear Science and Numerical Simulation_, *17*(12), 4831-4845. doi: [10.1016/j.cnsns.2012.05.010 ](https://doi.org/10.1016/j.cnsns.2012.05.010 )

### L
- **<u>Ladybirds</u>**: Wang P, Zhu Z, Huang S (2013). “Seven-Spot Ladybird Optimization: A Novel and Efficient Metaheuristic Algorithm for Numerical Optimization.” _The Scientific World Journal_, *2013*, 1-11. doi: [10.1155/2013/378515 ](https://doi.org/10.1155/2013/378515 )
- **<u>Lightning</u>**: Shareef H, Ibrahim AA, Mutlag AH (2015). “Lightning search algorithm.” _Applied Soft Computing_, *36*, 315-333. doi: [10.1016/j.asoc.2015.07.028 ](https://doi.org/10.1016/j.asoc.2015.07.028 )
- **<u>Lions</u>**: Wang B, Jin X, Cheng B (2012). “Lion pride optimizer: An optimization algorithm inspired by lion pride behavior.” _Science China Information Sciences_, *55*(10), 2369-2389. doi: [10.1007/s11432-012-4548-0 ](https://doi.org/10.1007/s11432-012-4548-0 )
- **<u>Locusts</u>**: Chen S (2009). “An Analysis of Locust Swarms on Large Scale Global Optimization Problems.” In _Artificial Life: Borrowing from Biology_, 211-220. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-10427-5_21 ](https://doi.org/10.1007/978-3-642-10427-5_21 )

### M
- **<u>Markets</u>**: Ghorbani N, Babaei E (2014). “Exchange market algorithm.” _Applied Soft Computing_, *19*, 177-187. doi: [10.1016/j.asoc.2014.02.006 ](https://doi.org/10.1016/j.asoc.2014.02.006 )
- **<u>Mine Explosions</u>**: Sadollah A, Bahreininejad A, Eskandar H, Hamdi M (2012). “Mine blast algorithm for optimization of truss structures with discrete variables.” _Computers \& Structures_, *102-103*, 49-63. doi: [10.1016/j.compstruc.2012.03.013 ](https://doi.org/10.1016/j.compstruc.2012.03.013 )
- **<u>Monkeys: Monkey Foraging</u>**: Mucherino A, Seref O, Seref O, Kundakcioglu OE, Pardalos P (2007). “Monkey search: a novel metaheuristic search for global optimization.” In _AIP Conference Proceedings_. doi: [10.1063/1.2817338 ](https://doi.org/10.1063/1.2817338 )
- **<u>Monkeys: Spider Monkeys</u>**: Bansal JC, Sharma H, Jadon SS, Clerc M (2014). “Spider Monkey Optimization algorithm for numerical optimization.” _Memetic Computing_, *6*(1), 31-47. doi: [10.1007/s12293-013-0128-0 ](https://doi.org/10.1007/s12293-013-0128-0 )
- **<u>Moths</u>**: Mirjalili S (2015). “Moth-flame optimization algorithm: A novel nature-inspired heuristic paradigm.” _Knowledge-Based Systems_, *89*, 228-249. doi: [10.1016/j.knosys.2015.07.006 ](https://doi.org/10.1016/j.knosys.2015.07.006 )
- **<u>Mountain Climbers</u>**: Zhang LM, Dahlmann C, Zhang Y (2009). “Human-Inspired Algorithms for continuous function optimization.” In _2009 IEEE International Conference on Intelligent Computing and Intelligent Systems_. doi: [10.1109/icicisys.2009.5357838 ](https://doi.org/10.1109/icicisys.2009.5357838 )
- **<u>Multiverse</u>**: Mirjalili S, Mirjalili SM, Hatamlou A (2015). “Multi-Verse Optimizer: a nature-inspired algorithm for global optimization.” _Neural Computing and Applications_, *27*(2), 495-513. doi: [10.1007/s00521-015-1870-7 ](https://doi.org/10.1007/s00521-015-1870-7 )
- **<u>Musicians</u>**: Geem ZW, Kim JH, Loganathan G (2001). “A New Heuristic Optimization Algorithm: Harmony Search.” _SIMULATION_, *76*(2), 60-68. doi: [10.1177/003754970107600201 ](https://doi.org/10.1177/003754970107600201 )

### N
- **<u>Neurons</u>**: Asil Gharebaghi S, Ardalan Asl M (2017). “NEW META-HEURISTIC OPTIMIZATION ALGORITHM USING NEURONAL COMMUNICATION.” _ International Journal of Optimization in Civil Engineering_, *7*(3). http://ijoce.iust.ac.ir/article-1-306-en.pdf, <URL: http://ijoce.iust.ac.ir/article-1-306-en.html>.
- **<u>Newton's Cooling Law</u>**: Kaveh A, Dadras A (2017). “A novel meta-heuristic optimization algorithm: Thermal exchange optimization.” _Advances in Engineering Software_, *110*, 69-84. doi: [10.1016/j.advengsoft.2017.03.014 ](https://doi.org/10.1016/j.advengsoft.2017.03.014 )

### O
- **<u>Optics</u>**: Kashan AH (2015). “A new metaheuristic for optimization: Optics inspired optimization (OIO).” _Computers \& Operations Research_, *55*, 99-125. doi: [10.1016/j.cor.2014.10.011 ](https://doi.org/10.1016/j.cor.2014.10.011 )

### P
- **<u>Paddy Fields</u>**: Premaratne U, Samarabandu J, Sidhu T (2009). “A new biologically inspired optimization algorithm.” In _2009 International Conference on Industrial and Information Systems (ICIIS)_. doi: [10.1109/iciinfs.2009.5429852 ](https://doi.org/10.1109/iciinfs.2009.5429852 )
- **<u>Parliamentarist Elections</u>**: Borji A (2007). “A New Global Optimization Algorithm Inspired by Parliamentary Political Competitions.” In _MICAI 2007: Advances in Artificial Intelligence_, 61-71. Springer Berlin Heidelberg. doi: [10.1007/978-3-540-76631-5_7 ](https://doi.org/10.1007/978-3-540-76631-5_7 )
- **<u>Penguins</u>**: Gheraibia Y, Moussaoui A (2013). “Penguins Search Optimization Algorithm (PeSOA).” In _Recent Trends in Applied Artificial Intelligence_, 222-231. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-38577-3_23 ](https://doi.org/10.1007/978-3-642-38577-3_23 )
- **<u>Peral Hunting</u>**: Chan CY, Xue F, Ip WH, Cheung CF (2012). “A Hyper-Heuristic Inspired by Pearl Hunting.” In _Lecture Notes in Computer Science_, 349-353. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-34413-8_26 ](https://doi.org/10.1007/978-3-642-34413-8_26 )
- **<u>Plants: Plant Growth</u>**: Li J, Cui Z, Shi Z (2012). “An Improved Artificial Plant Optimization Algorithm for Coverage Problem in WSN.” _Sensor Letters_, *10*(8), 1874-1878. doi: [10.1166/sl.2012.2627 ](https://doi.org/10.1166/sl.2012.2627 )
- **<u>Plants: Plant Intelligence</u>**: Akyol S, Alatas B (2016). “Plant intelligence based metaheuristic optimization algorithms.” _Artificial Intelligence Review_, *47*(4), 417-462. doi: [10.1007/s10462-016-9486-6 ](https://doi.org/10.1007/s10462-016-9486-6 )
- **<u>Plants: Plant Propagation</u>**: Sulaiman M, Salhi A, Selamoglu BI, Kirikchi OB (2014). “A Plant Propagation Algorithm for Constrained Engineering Optimisation Problems.” _Mathematical Problems in Engineering_, *2014*, 1-10. doi: [10.1155/2014/627416 ](https://doi.org/10.1155/2014/627416 )
- **<u>Political Imperialism</u>**: Atashpaz-Gargari E, Lucas C (2007). “Imperialist competitive algorithm: An algorithm for optimization inspired by imperialistic competition.” In _2007 IEEE Congress on Evolutionary Computation_. doi: [10.1109/cec.2007.4425083 ](https://doi.org/10.1109/cec.2007.4425083 )
- **<u>Political Strategies</u>**: Melvix JL (2014). “Greedy Politics Optimization: Metaheuristic inspired by political strategies adopted during state assembly elections.” In _2014 IEEE International Advance Computing Conference (IACC)_. doi: [10.1109/iadcc.2014.6779490 ](https://doi.org/10.1109/iadcc.2014.6779490 )

### Q
- **<u>Quantum Superposition</u>**: Saire JEC, Tupac VYJ (2015). “An approach to real-coded quantum inspired evolutionary algorithm using particles filter.” In _2015 Latin America Congress on Computational Intelligence (LA-CCI)_. doi: [10.1109/la-cci.2015.7435984 ](https://doi.org/10.1109/la-cci.2015.7435984 )

### R
- **<u>Ravens</u>**: Torabi S, Safi-Esfahani F (2017). “Improved Raven Roosting Optimization algorithm (IRRO).” _Swarm and Evolutionary Computation_. doi: [10.1016/j.swevo.2017.11.006 ](https://doi.org/10.1016/j.swevo.2017.11.006 )
- **<u>Rays of Light</u>**: Kaveh A, Khayatazad M (2012). “A new meta-heuristic method: Ray Optimization.” _Computers \& Structures_, *112-113*, 283-294. doi: [10.1016/j.compstruc.2012.09.003 ](https://doi.org/10.1016/j.compstruc.2012.09.003 )
- **<u>Reincarnation</u>**: Sharma A (2010). “A new optimizing algorithm using reincarnation concept.” In _2010 11th International Symposium on Computational Intelligence and Informatics (CINTI)_. doi: [10.1109/cinti.2010.5672231 ](https://doi.org/10.1109/cinti.2010.5672231 )
- **<u>Rhinoceros</u>**: Deb S, Tian Z, Fong S, Tang R, Wong R, Dey N (2018). “Solving permutation flow-shop scheduling problem by rhinoceros search algorithm.” _Soft Computing_. doi: [10.1007/s00500-018-3075-3 ](https://doi.org/10.1007/s00500-018-3075-3 )
- **<u>River Formation</u>**: Rabanal P, Rodr\'\iguez I, Rubio F (2007). “Using River Formation Dynamics to Design Heuristic Algorithms.” In _Lecture Notes in Computer Science_, 163-177. Springer Berlin Heidelberg. doi: [10.1007/978-3-540-73554-0_16 ](https://doi.org/10.1007/978-3-540-73554-0_16 )
- **<u>Roach Infestations</u>**: Havens TC, Spain CJ, Salmon NG, Keller JM (2008). “Roach Infestation Optimization.” In _2008 IEEE Swarm Intelligence Symposium_. doi: [10.1109/sis.2008.4668317 ](https://doi.org/10.1109/sis.2008.4668317 )
- **<u>Roots</u>**: Merrikh-Bayat F (2015). “The runner-root algorithm: A metaheuristic for solving unimodal and multimodal optimization problems inspired by runners and roots of plants in nature.” _Applied Soft Computing_, *33*, 292-303. doi: [10.1016/j.asoc.2015.04.048 ](https://doi.org/10.1016/j.asoc.2015.04.048 )

### S
- **<u>Salmon Migrations</u>**: Mozaffari A, Fathi A, Behzadipour S (2012). “The great salmon run: a novel bio-inspired algorithm for artificial system design and optimisation.” _International Journal of Bio-Inspired Computation_, *4*(5), 286-301.
- **<u>Salp Planktons</u>**: Mirjalili S, Gandomi AH, Mirjalili SZ, Saremi S, Faris H, Mirjalili SM (2017). “Salp Swarm Algorithm: A bio-inspired optimizer for engineering design problems.” _Advances in Engineering Software_, *114*, 163-191. doi: [10.1016/j.advengsoft.2017.07.002 ](https://doi.org/10.1016/j.advengsoft.2017.07.002 )
- **<u>Scientific Method</u>**: Felipe D, Goldbarg EFG, Goldbarg MC (2014). “Scientific algorithms for the Car Renter Salesman Problem.” In _2014 IEEE Congress on Evolutionary Computation (CEC)_. doi: [10.1109/cec.2014.6900556 ](https://doi.org/10.1109/cec.2014.6900556 )
- **<u>See-See Partridges</u>**: Omidvar R, Parvin H, Rad F (2015). “SSPCO Optimization Algorithm (See-See Partridge Chicks Optimization).” In _2015 Fourteenth Mexican International Conference on Artificial Intelligence (MICAI)_. doi: [10.1109/micai.2015.22 ](https://doi.org/10.1109/micai.2015.22 )
- **<u>Sharks</u>**: Abedinia O, Amjady N, Ghasemi A (2014). “A new metaheuristic algorithm based on shark smell optimization.” _Complexity_, *21*(5), 97-116. doi: [10.1002/cplx.21634 ](https://doi.org/10.1002/cplx.21634 )
- **<u>Sheep Flocks</u>**: Kim H, Ahn B (2001). “A new evolutionary algorithm based on sheep flocks heredity model.” In _2001 IEEE Pacific Rim Conference on Communications, Computers and Signal Processing (IEEE Cat. No.01CH37233)_. doi: [10.1109/pacrim.2001.953683 ](https://doi.org/10.1109/pacrim.2001.953683 )
- **<u>Small World</u>**: Du H, Wu X, Zhuang J (2006). “Small-World Optimization Algorithm for Function Optimization.” In _Lecture Notes in Computer Science_, 264-273. Springer Berlin Heidelberg. doi: [10.1007/11881223_33 ](https://doi.org/10.1007/11881223_33 )
- **<u>Soccer Games</u>**: Purnomo HD, Wee H (2013). “Soccer Game Optimization.” In _Meta-Heuristics Optimization Algorithms in Engineering, Business, Economics, and Finance_, 386-420. IGI Global. doi: [10.4018/978-1-4666-2086-5.ch013 ](https://doi.org/10.4018/978-1-4666-2086-5.ch013 )
- **<u>Social Behavior</u>**: Ray T, Liew K (2003). “Society and civilization: an optimization algorithm based on the simulation of social behavior.” _IEEE Transactions on Evolutionary Computation_, *7*(4), 386-396. doi: [10.1109/tevc.2003.814902 ](https://doi.org/10.1109/tevc.2003.814902 )
- **<u>Social Engineering</u>**: Fard AMF, Hajiaghaei-Keshteli M (2017). “Social Engineering Optimization (SEO); A New Single-Solution Meta-heuristic Inspired by Social Engineering.” In _International Conference on Industrial Engineering_.
- **<u>Social Spiders</u>**: Cuevas E, Cienfuegos M, Zald\'\ivar D, Pérez-Cisneros M (2013). “A swarm optimization algorithm inspired in the behavior of the social-spider.” _Expert Systems with Applications_, *40*(16), 6374-6384. doi: [10.1016/j.eswa.2013.05.041 ](https://doi.org/10.1016/j.eswa.2013.05.041 )
- **<u>Sonar</u>**: Tzanetos A, Dounias G (2017). “A New Metaheuristic Method for Optimization: Sonar Inspired Optimization.” In Boracchi G, Iliadis L, Jayne C, Likas A (eds.), _Engineering Applications of Neural Networks_, 417-428. ISBN 978-3-319-65172-9.
- **<u>Sperm</u>**: Raouf OA, Hezam IM (2017). “Sperm motility algorithm: a novel metaheuristic approach for global optimisation.” _International Journal of Operational Research_, *28*(2), 143. doi: [10.1504/ijor.2017.10002079 ](https://doi.org/10.1504/ijor.2017.10002079 )
- **<u>Spirals</u>**: Tamura K, and Keiichiro Yasuda (2011). “Spiral Dynamics Inspired Optimization.” _Journal of Advanced Computational Intelligence and Intelligent Informatics_, *15*(8), 1116-1122. doi: [10.20965/jaciii.2011.p1116 ](https://doi.org/10.20965/jaciii.2011.p1116 )
- **<u>Sports Championships</u>**: Kashan AH (2009). “League Championship Algorithm: A New Algorithm for Numerical Function Optimization.” In _2009 International Conference of Soft Computing and Pattern Recognition_. doi: [10.1109/socpar.2009.21 ](https://doi.org/10.1109/socpar.2009.21 )
- **<u>Squirrels: Flying Squirrels</u>**: Jain M, Singh V, Rani A (2018). “A novel nature-inspired algorithm for optimization: Squirrel search algorithm.” _Swarm and Evolutionary Computation_. doi: [10.1016/j.swevo.2018.02.013 ](https://doi.org/10.1016/j.swevo.2018.02.013 )
- **<u>States of Matter</u>**: Cuevas E, Echavarr\'\ia A, Ram\'\irez-Ortegón MA (2013). “An optimization algorithm inspired by the States of Matter that improves the balance between exploration and exploitation.” _Applied Intelligence_, *40*(2), 256-272. doi: [10.1007/s10489-013-0458-0 ](https://doi.org/10.1007/s10489-013-0458-0 )
- **<u>Swallows</u>**: Neshat M, Sepidnam G, Sargolzaei M (2012). “Swallow swarm optimization algorithm: a new method to optimization.” _Neural Computing and Applications_, *23*(2), 429-454. doi: [10.1007/s00521-012-0939-9 ](https://doi.org/10.1007/s00521-012-0939-9 )
- **<u>Symbiotic Organisms</u>**: Cheng M, Prayogo D (2014). “Symbiotic Organisms Search: A new metaheuristic optimization algorithm.” _Computers \& Structures_, *139*, 98-112. doi: [10.1016/j.compstruc.2014.03.007 ](https://doi.org/10.1016/j.compstruc.2014.03.007 )

### T
- **<u>Teachers</u>**: Rao R, Savsani V, Vakharia D (2011). “Teaching\textendashlearning-based optimization: A novel method for constrained mechanical design optimization problems.” _Computer-Aided Design_, *43*(3), 303-315. doi: [10.1016/j.cad.2010.12.015 ](https://doi.org/10.1016/j.cad.2010.12.015 )
- **<u>Termites</u>**: Hedayatzadeh R, Salmassi FA, Keshtgari M, Akbari R, Ziarati K (2010). “Termite colony optimization: A novel approach for optimizing continuous problems.” In _2010 18th Iranian Conference on Electrical Engineering_. doi: [10.1109/iraniancee.2010.5507009 ](https://doi.org/10.1109/iraniancee.2010.5507009 )
- **<u>Troops of Soldiers</u>**: Chen T (2009). “A Simulative Bionic Intelligent Optimization Algorithm: Artificial Searching Swarm Algorithm and Its Performance Analysis.” In _2009 International Joint Conference on Computational Sciences and Optimization_. doi: [10.1109/cso.2009.183 ](https://doi.org/10.1109/cso.2009.183 )
- **<u>Tug of War</u>**: Kaveh A, Zolghadr A (2016). “A novel meta-heuristic algorithm: tug of war optimization.” _Iran University of Science \& Technology_, *6*(4), 469-492.

### U

### V
- **<u>Vaccination</u>**: Tayeb FB, Bessedik M, Benbouzid M, Cheurfi H, Blizak A (2017). “Research on Permutation Flow-shop Scheduling Problem based on Improved Genetic Immune Algorithm with vaccinated offspring.” _Procedia Computer Science_, *112*, 427-436. doi: [10.1016/j.procs.2017.08.055 ](https://doi.org/10.1016/j.procs.2017.08.055 )
- **<u>Vehicles</u>**: Savsani P, Savsani V (2016). “Passing vehicle search (PVS): A novel metaheuristic algorithm.” _Applied Mathematical Modelling_, *40*(5-6), 3951-3978. doi: [10.1016/j.apm.2015.10.040 ](https://doi.org/10.1016/j.apm.2015.10.040 )
- **<u>Vibrating Particles</u>**: Kaveh A, Ghazaan MI (2016). “Vibrating particles system algorithm for truss optimization with multiple natural frequency constraints.” _Acta Mechanica_, *228*(1), 307-322. doi: [10.1007/s00707-016-1725-z ](https://doi.org/10.1007/s00707-016-1725-z )
- **<u>Virus: Swine Flu</u>**: Pattnaik S, Bakwad K, Sohi B, Ratho R, Devi S (2013). “Swine Influenza Models Based Optimization (SIMBO).” _Applied Soft Computing_, *13*(1), 628-653. doi: [10.1016/j.asoc.2012.07.010 ](https://doi.org/10.1016/j.asoc.2012.07.010 )
- **<u>Viruses: Virulence</u>**: Jaderyan M, Khotanlou H (2016). “Virulence Optimization Algorithm.” _Applied Soft Computing_, *43*, 596-618. doi: [10.1016/j.asoc.2016.02.038 ](https://doi.org/10.1016/j.asoc.2016.02.038 )
- **<u>Viruses: Virus Colonies</u>**: Li MD, Zhao H, Weng XW, Han T (2016). “A novel nature-inspired algorithm for optimization: Virus colony search.” _Advances in Engineering Software_, *92*, 65-88. doi: [10.1016/j.advengsoft.2015.11.004 ](https://doi.org/10.1016/j.advengsoft.2015.11.004 )
- **<u>Viruses: Virus Replication</u>**: Cortés P, Garc\'\ia JM, Muñuzuri J, Onieva L (2008). “Viral systems: A new bio-inspired optimisation approach.” _Computers \& Operations Research_, *35*(9), 2840-2860. doi: [10.1016/j.cor.2006.12.018 ](https://doi.org/10.1016/j.cor.2006.12.018 )
- **<u>Volleyball Leagues</u>**: Moghdani R, Salimifard K (2018). “Volleyball Premier League Algorithm.” _Applied Soft Computing_, *64*, 161-185. doi: [10.1016/j.asoc.2017.11.043 ](https://doi.org/10.1016/j.asoc.2017.11.043 )
- **<u>Vortices</u>**: Doğan B, Ölmez T (2015). “A new metaheuristic for numerical function optimization: Vortex Search algorithm.” _Information Sciences_, *293*, 125-145. doi: [10.1016/j.ins.2014.08.053 ](https://doi.org/10.1016/j.ins.2014.08.053 )
- **<u>Vultures</u>**: Sur C, Sharma S, Shukla A (2013). “Egyptian Vulture Optimization Algorithm \textendash A New Nature Inspired Meta-heuristics for Knapsack Problem.” In _The 9th International Conference on Computing and InformationTechnology (IC2IT2013)_, 227-237. Springer Berlin Heidelberg. doi: [10.1007/978-3-642-37371-8_26 ](https://doi.org/10.1007/978-3-642-37371-8_26 )

### W
- **<u>Wasps</u>**: Pinto P, Runkler TA, Sousa JM (2005). “Wasp swarm optimization of logistic systems.” In _Adaptive and Natural Computing Algorithms_, 264-267. Springer.
- **<u>Water: Hydrological Cycle</u>**: Wedyan A, Whalley J, Narayanan A (2017). “Hydrological Cycle Algorithm for Continuous Optimization Problems.” _Journal of Optimization_, *2017*, 1-25. doi: [10.1155/2017/3828420 ](https://doi.org/10.1155/2017/3828420 )
- **<u>Water: Intelligent Water Drops</u>**: Hosseini HS (2009). “The intelligent water drops algorithm: a nature-inspired swarm-based optimization algorithm.” _International Journal of Bio-Inspired Computation_, *1*(1/2), 71. doi: [10.1504/ijbic.2009.022775 ](https://doi.org/10.1504/ijbic.2009.022775 )
- **<u>Water: Rain</u>**: Kaboli SHA, Selvaraj J, Rahim N (2017). “Rain-fall optimization algorithm: A population based algorithm for solving constrained optimization problems.” _Journal of Computational Science_, *19*, 31-42. doi: [10.1016/j.jocs.2016.12.010 ](https://doi.org/10.1016/j.jocs.2016.12.010 )
- **<u>Water: Rain Drops</u>**: Jiang Q, Wang L, Hei X, Fei R, Yang D, Zou F, Li H, Cao Z, Lin Y (2014). “Optimal approximation of stable linear systems with a novel and efficient optimization algorithm.” In _2014 IEEE Congress on Evolutionary Computation (CEC)_. doi: [10.1109/cec.2014.6900366 ](https://doi.org/10.1109/cec.2014.6900366 )
- **<u>Water: Water Cycle</u>**: Eskandar H, Sadollah A, Bahreininejad A, Hamdi M (2012). “Water cycle algorithm \textendash A novel metaheuristic optimization method for solving constrained engineering optimization problems.” _Computers \& Structures_, *110-111*, 151-166. doi: [10.1016/j.compstruc.2012.07.010 ](https://doi.org/10.1016/j.compstruc.2012.07.010 )
- **<u>Water: Water Evaporation</u>**: Kaveh A, Bakhshpoori T (2016). “Water Evaporation Optimization: A novel physically inspired optimization algorithm.” _Computers \& Structures_, *167*, 69-85. doi: [10.1016/j.compstruc.2016.01.008 ](https://doi.org/10.1016/j.compstruc.2016.01.008 )
- **<u>Water: Water Flow</u>**: Tran TH, Ng KM (2010). “A water-flow algorithm for flexible flow shop scheduling with~intermediate buffers.” _Journal of Scheduling_, *14*(5), 483-500. doi: [10.1007/s10951-010-0205-x ](https://doi.org/10.1007/s10951-010-0205-x )
- **<u>Water: Water Wave</u>**: Zheng Y (2015). “Water wave optimization: A new nature-inspired metaheuristic.” _Computers \& Operations Research_, *55*, 1-11. doi: [10.1016/j.cor.2014.10.008 ](https://doi.org/10.1016/j.cor.2014.10.008 )
- **<u>Whales: Killer Whales</u>**: Biyanto TR, Matradji, Irawan S, Febrianto HY, Afdanny N, Rahman AH, Gunawan KS, Pratama JA, Bethiana TN (2017). “Killer Whale Algorithm: An Algorithm Inspired by the Life of Killer Whale.” _Procedia Computer Science_, *124*, 151-157. doi: [10.1016/j.procs.2017.12.141 ](https://doi.org/10.1016/j.procs.2017.12.141 )
- **<u>Whales: Regular Whales</u>**: Mirjalili S, Lewis A (2016). “The Whale Optimization Algorithm.” _Advances in Engineering Software_, *95*, 51-67. doi: [10.1016/j.advengsoft.2016.01.008 ](https://doi.org/10.1016/j.advengsoft.2016.01.008 )
- **<u>Whales: Sperm Whales</u>**: Ebrahimi A, Khamehchi E (2016). “Sperm whale algorithm: An effective metaheuristic algorithm for production optimization problems.” _Journal of Natural Gas Science and Engineering_, *29*, 211-222. doi: [10.1016/j.jngse.2016.01.001 ](https://doi.org/10.1016/j.jngse.2016.01.001 )
- **<u>Wind</u>**: Bayraktar Z, Komurcu M, Werner DH (2010). “Wind Driven Optimization (WDO): A novel nature-inspired optimization algorithm and its application to electromagnetics.” In _2010 IEEE Antennas and Propagation Society International Symposium_. doi: [10.1109/aps.2010.5562213 ](https://doi.org/10.1109/aps.2010.5562213 )
- **<u>Wolves: Grey Wolves</u>**: Mirjalili S, Mirjalili SM, Lewis A (2014). “Grey Wolf Optimizer.” _Advances in Engineering Software_, *69*, 46-61. doi: [10.1016/j.advengsoft.2013.12.007 ](https://doi.org/10.1016/j.advengsoft.2013.12.007 )
- **<u>Wolves: Wolves</u>**: Tang R, Fong S, Yang X, Deb S (2012). “Wolf search algorithm with ephemeral memory.” In _Seventh International Conference on Digital Information Management (ICDIM 2012)_. doi: [10.1109/icdim.2012.6360147 ](https://doi.org/10.1109/icdim.2012.6360147 )
- **<u>Worms</u>**: Arnaout J (2014). “Worm optimization: a novel optimization algorithm inspired by C. Elegans.” In _Proceedings of the 2014 International Conference on Industrial Engineering and Operations Management_, 2499-2505.

### X

### Y
- **<u>Yin-Yang Pairs</u>**: Punnathanam V, Kotecha P (2016). “Yin-Yang-pair Optimization: A novel lightweight optimization algorithm.” _Engineering Applications of Artificial Intelligence_, *54*, 62-79. doi: [10.1016/j.engappai.2016.04.004 ](https://doi.org/10.1016/j.engappai.2016.04.004 )

### Z
- **<u>Zombies</u>**: Nguyen HT, Bhanu B (2012). “Zombie Survival Optimization: A swarm intelligence algorithm inspired by zombie foraging.” In _Pattern Recognition (ICPR), 2012 21st International Conference on_, 987-990. IEEE.

***

### Maintainers
("the Zoo Keepers")

- [Claus Aranha](mailto:caranha@cs.tsukuba.ac.jp), Tsukuba University, Japan.  
- [Felipe Campelo](mailto:fcampelo@ufmg.br), Universidade Federal de Minas Gerais (UFMG), Brazil.

### Contributors
(at least one contribution to the bestiary - in terms of adding a method to the list, not inventing it!)

- Adré Steyn - University of Stellenbosch, South Africa
- Alberto Franzin - Université Libre de Bruxelles, Belgium
- André Maravilha - UFMG, Brazil
- Carlos Fonseca - University of Coimbra, Portugal
- Ciniro Nametala - UFMG, Brazil
- Eduardo Hauck - UFJF, Brazil
- Fabio Daolio - University of Stirling, Scotland UK
- Fernanda Takahashi - UFMG, Brazil
- Fernando Otero - University of Kent, England UK
- Fillipe Goulart - UFMG, Brazil
- Federico Pagnozzi - Université Libre de Bruxelles, Belgium
- Iago A. de Carvalho - UFMG, Brazil
- Iztok Fister Jr. - University of Maribor, Slovenia
- Jakub Grabski - Poznan University of Technology, Poland
- Kenneth Sörensen - University of Antwerp, Belgium
- Lars Magnus Hvattum - Molde University College, Norway
- Marc Sevaux - Université de Bretagne-Sud, France
- Marco Mollinetti - University of Tsukuba, Japan
- Marco Pranzo - Università di Siena, Italy
- Marcus Ritt - UFRGS, Brazil
- Nadarajen Veerapen - University of Stirling, Scotland UK
- Robin Purshouse - University of Sheffield, England UK
- Rubén Ruiz - Universitat Politècnica de València, Spain
- Ruud Koot - Universiteit Utrecht, The Netherlands
- Sara Silva - University of Lisbon
- Sergio A. Rojas - Universidad Distrital de Bogotá, Colombia
- Silvano Martello - University of Bologna
- Stefan Voß - Universität Hamburg, Germany
- Thomas Jacob Riis Stidsen - Danmarks Tekniske Universitet, Denmark
- Thomas Stützle - Université Libre de Bruxelles, Belgium

***

### How to Contribute

If you know a paper that should belong to this list, please send an
e-mail to either [Claus](mailto:caranha@cs.tsukuba.ac.jp) or [Felipe](mailto:fcampelo@ufmg.br), or report an issue on our [Github repo](https://github.com/fcampelo/EC-bestiary). The criteria for inclusion are quite simple: 

1. the work must be in a peer reviewed publication (journal or conference);  
2. the title or abstract must name the algorithm after the natural (or supernatural) metaphor on which it was based;  

It is also important to highlight that only the earliest known mention for each metaphor is included.

### More Info:
- If you liked this list, you should read the paper "[Metaheuristic: The Metaphor Exposed](http://onlinelibrary.wiley.com/doi/10.1111/itor.12001/epdf)", by Kenneth Söresen  
- Need inspiration for your next Bioinspired algorithm? Check Marco Scirea and Julian Togelius' [Daily Bio-heuristics bot](https://twitter.com/BioHeuristics).  
- Some of the algorithms listed here were found in a list compiled by Iztok Fister Jr. _et al._, which is available [here](http://www.iztok-jr-fister.eu/static/publications/21.pdf). Iztok also recently published [this paper](http://www.iztok-jr-fister.eu/static/publications/Stu2016.pdf) reflecting on the proliferation of metaphors in EC research.  
- A fantastic parody of this whole metaphor craze can be read [here](http://www.oneweirdkerneltrick.com/spectral.pdf). Highly recommended!

### License:
This work is licensed under the Creative Commons CC BY-NC-SA 4.0 license (Attribution Non-Commercial Share Alike International License version 4.0): [http://creativecommons.org/licenses/by-nc-sa/4.0/](http://creativecommons.org/licenses/by-nc-sa/4.0/)
